import { View, Platform } from 'react-native';
import { useLinkBuilder, useTheme } from '@react-navigation/native';
import { Text, PlatformPressable } from '@react-navigation/elements';
import { createBottomTabNavigator } from '@react-navigation/bottom-tabs';
import colors from 'tailwindcss/colors';
import React from 'react';
import MenuItem from './menu-item';
import { FullCircleIcon } from './icons/full-circle';
import { EmptyCircleIcon } from './icons/empty-circle';

export const BottomNavigation = ({
  state,
  descriptors,
  navigation,
  shadow = false,
  divider = false,
}) => {
  const { colors } = useTheme();
  const { buildHref } = useLinkBuilder();

  console.log(state);

  const dividerClassFlag = divider ? 'border-t border-blue-500' : '';

  return (
    <View
      className="h-[86px]"
      style={{ flexDirection: 'row', backgroundColor: 'tra' }}
    >
      {state.routes.map((route, index) => {
        const { options } = descriptors[route.key];
        const label =
          options.tabBarLabel !== undefined
            ? options.tabBarLabel
            : options.title !== undefined
              ? options.title
              : route.name;

        const isFocused = state.index === index;

        const onPress = () => {
          const event = navigation.emit({
            type: 'tabPress',
            target: route.key,
            canPreventDefault: true,
          });

          if (!isFocused && !event.defaultPrevented) {
            navigation.navigate(route.name, route.params);
          }
        };

        const onLongPress = () => {
          navigation.emit({
            type: 'tabLongPress',
            target: route.key,
          });
        };

        return (
          <PlatformPressable
            pressOpacity={1}
            href={buildHref(route.name, route.params)}
            accessibilityState={isFocused ? { selected: true } : {}}
            accessibilityLabel={options.tabBarAccessibilityLabel}
            testID={options.tabBarButtonTestID}
            onPress={onPress}
            onLongPress={onLongPress}
            className={`flex-1 ${dividerClassFlag} bg-white justify-center items-center pb-[20px]`}
          >
            <MenuItem
              activeIcon={<FullCircleIcon />}
              idleIcon={<EmptyCircleIcon />}
              menuTitle={label}
              selected={isFocused}
            />
            {/* <Text style={{ color: isFocused ? colors.primary : colors.text }}>
              {label}
            </Text> */}
          </PlatformPressable>
        );
      })}
    </View>
  );
};
